boviz package
=============

Submodules
----------

boviz.cli module
----------------

.. automodule:: boviz.cli
   :members:
   :show-inheritance:
   :undoc-members:

boviz.config module
-------------------

.. automodule:: boviz.config
   :members:
   :show-inheritance:
   :undoc-members:

boviz.curves module
-------------------

.. automodule:: boviz.curves
   :members:
   :show-inheritance:
   :undoc-members:

boviz.heatmap module
--------------------

.. automodule:: boviz.heatmap
   :members:
   :show-inheritance:
   :undoc-members:

boviz.histogram module
----------------------

.. automodule:: boviz.histogram
   :members:
   :show-inheritance:
   :undoc-members:

boviz.schematic module
----------------------

.. automodule:: boviz.schematic
   :members:
   :show-inheritance:
   :undoc-members:

boviz.style module
------------------

.. automodule:: boviz.style
   :members:
   :show-inheritance:
   :undoc-members:

boviz.utils module
------------------

.. automodule:: boviz.utils
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: boviz
   :members:
   :show-inheritance:
   :undoc-members:
